@@ -12,8 +12,10 @@ from .wait_command import wait_command
 from .settings import settings
 from .gitignore import gitignore
 from .black import black
+from .flake8 import flake8
 from .banditrc import banditrc
 from .dependencies import dependencies
+from .reformat import reformat
 
 log = logging.getLogger()
 
@@ -37,9 +39,6 @@ class Backend(Component):
         log.warning(f"Deleting the {Projects.BACKEND} project")
         shutil.rmtree(Projects.BACKEND)
 
-    def deploy(self):
-        pass
-
     @property
     def installed(self):
         return os.path.exists(Projects.BACKEND)
@@ -54,5 +53,8 @@ backend = Backend(
         gitignore,
         black,
         banditrc,
+        flake8,
+        # It is important that this comes last, so all relevant items can be reformatted
+        reformat,
     ]
 )
