@@ -18,12 +18,12 @@ class Dependencies(Component):
             "djangorestframework-camel-case",
         ]
 
-        dev_dependencies = ["django-anymail", "pytz", "factory-boy"]
+        dev_dependencies = ["django-anymail", "pytz", "factory-boy", "flake8-black", "bandit"]
 
         log.info("Installing production dependencies")
         install_dependencies(*dependencies)
 
-        log.info("Installing dev depencies")
+        log.info("Installing dev dependencies")
         install_dependencies(*dev_dependencies, dev=True)
 
     def update(self):
